pub struct DrawOrder(/* private fields */);Expand description
A struct representing the draw order of an entity Higher draw orders will be drawn on top of lower draw orders
Implementations
Methods from Deref<Target = f32>
pub const RADIX: u32 = 2
pub const BITS: u32 = 32
pub const MANTISSA_DIGITS: u32 = 24
pub const DIGITS: u32 = 6
pub const EPSILON: f32 = 1.19209290e-07_f32
pub const MIN: f32 = -3.40282347e+38_f32
pub const MIN_POSITIVE: f32 = 1.17549435e-38_f32
pub const MAX: f32 = 3.40282347e+38_f32
pub const MIN_EXP: i32 = -125
pub const MAX_EXP: i32 = 128
pub const MIN_10_EXP: i32 = -37
pub const MAX_10_EXP: i32 = 38
pub const NAN: f32
pub const INFINITY: f32
pub const NEG_INFINITY: f32
pub const MAX_EXACT_INTEGER: i32
pub const MIN_EXACT_INTEGER: i32
pub const SIGN_MASK: u32 = 0x8000_0000
pub const EXPONENT_MASK: u32 = 0x7f80_0000
pub const MANTISSA_MASK: u32 = 0x007f_ffff
1.62.0 · Sourcepub fn total_cmp(&self, other: &f32) -> Ordering
pub fn total_cmp(&self, other: &f32) -> Ordering
Returns the ordering between self and other.
Unlike the standard partial comparison between floating point numbers,
this comparison always produces an ordering in accordance to
the totalOrder predicate as defined in the IEEE 754 (2008 revision)
floating point standard. The values are ordered in the following sequence:
- negative quiet NaN
- negative signaling NaN
- negative infinity
- negative numbers
- negative subnormal numbers
- negative zero
- positive zero
- positive subnormal numbers
- positive numbers
- positive infinity
- positive signaling NaN
- positive quiet NaN.
The ordering established by this function does not always agree with the
PartialOrd and PartialEq implementations of f32. For example,
they consider negative and positive zero equal, while total_cmp
doesn’t.
The interpretation of the signaling NaN bit follows the definition in the IEEE 754 standard, which may not match the interpretation by some of the older, non-conformant (e.g. MIPS) hardware implementations.
Example
struct GoodBoy {
name: String,
weight: f32,
}
let mut bois = vec![
GoodBoy { name: "Pucci".to_owned(), weight: 0.1 },
GoodBoy { name: "Woofer".to_owned(), weight: 99.0 },
GoodBoy { name: "Yapper".to_owned(), weight: 10.0 },
GoodBoy { name: "Chonk".to_owned(), weight: f32::INFINITY },
GoodBoy { name: "Abs. Unit".to_owned(), weight: f32::NAN },
GoodBoy { name: "Floaty".to_owned(), weight: -5.0 },
];
bois.sort_by(|a, b| a.weight.total_cmp(&b.weight));
// `f32::NAN` could be positive or negative, which will affect the sort order.
if f32::NAN.is_sign_negative() {
assert!(bois.into_iter().map(|b| b.weight)
.zip([f32::NAN, -5.0, 0.1, 10.0, 99.0, f32::INFINITY].iter())
.all(|(a, b)| a.to_bits() == b.to_bits()))
} else {
assert!(bois.into_iter().map(|b| b.weight)
.zip([-5.0, 0.1, 10.0, 99.0, f32::INFINITY, f32::NAN].iter())
.all(|(a, b)| a.to_bits() == b.to_bits()))
}Trait Implementations
Sourceimpl AddAssign for DrawOrder
impl AddAssign for DrawOrder
Sourcefn add_assign(&mut self, rhs: DrawOrder)
fn add_assign(&mut self, rhs: DrawOrder)
+= operation. Read moreSourceimpl AddAssign<&DrawOrder> for DrawOrder
impl AddAssign<&DrawOrder> for DrawOrder
Sourcefn add_assign(&mut self, rhs: &DrawOrder)
fn add_assign(&mut self, rhs: &DrawOrder)
+= operation. Read moreSourceimpl AddAssign<&DrawOrder> for f32
impl AddAssign<&DrawOrder> for f32
Sourcefn add_assign(&mut self, rhs: &DrawOrder)
fn add_assign(&mut self, rhs: &DrawOrder)
+= operation. Read moreSourceimpl AddAssign<DrawOrder> for f32
impl AddAssign<DrawOrder> for f32
Sourcefn add_assign(&mut self, rhs: DrawOrder)
fn add_assign(&mut self, rhs: DrawOrder)
+= operation. Read moreSourceimpl AddAssign<f32> for DrawOrder
impl AddAssign<f32> for DrawOrder
Sourcefn add_assign(&mut self, rhs: f32)
fn add_assign(&mut self, rhs: f32)
+= operation. Read moreSourceimpl Component for DrawOrder
impl Component for DrawOrder
Sourceconst STORAGE_TYPE: StorageType = bevy::ecs::component::StorageType::Table
const STORAGE_TYPE: StorageType = bevy::ecs::component::StorageType::Table
Sourcefn register_component_hooks(_hooks: &mut ComponentHooks)
fn register_component_hooks(_hooks: &mut ComponentHooks)
ComponentHooks.impl Copy for DrawOrder
Sourceimpl<'de> Deserialize<'de> for DrawOrder
impl<'de> Deserialize<'de> for DrawOrder
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<DrawOrder, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<DrawOrder, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Sourceimpl DivAssign for DrawOrder
impl DivAssign for DrawOrder
Sourcefn div_assign(&mut self, rhs: DrawOrder)
fn div_assign(&mut self, rhs: DrawOrder)
/= operation. Read moreSourceimpl DivAssign<&DrawOrder> for DrawOrder
impl DivAssign<&DrawOrder> for DrawOrder
Sourcefn div_assign(&mut self, rhs: &DrawOrder)
fn div_assign(&mut self, rhs: &DrawOrder)
/= operation. Read moreSourceimpl DivAssign<&DrawOrder> for f32
impl DivAssign<&DrawOrder> for f32
Sourcefn div_assign(&mut self, rhs: &DrawOrder)
fn div_assign(&mut self, rhs: &DrawOrder)
/= operation. Read moreSourceimpl DivAssign<DrawOrder> for f32
impl DivAssign<DrawOrder> for f32
Sourcefn div_assign(&mut self, rhs: DrawOrder)
fn div_assign(&mut self, rhs: DrawOrder)
/= operation. Read moreSourceimpl DivAssign<f32> for DrawOrder
impl DivAssign<f32> for DrawOrder
Sourcefn div_assign(&mut self, rhs: f32)
fn div_assign(&mut self, rhs: f32)
/= operation. Read moreSourceimpl FromReflect for DrawOrder
impl FromReflect for DrawOrder
Sourcefn from_reflect(reflect: &(dyn Reflect + 'static)) -> Option<DrawOrder>
fn from_reflect(reflect: &(dyn Reflect + 'static)) -> Option<DrawOrder>
Self from a reflected value.Sourcefn take_from_reflect(
reflect: Box<dyn Reflect>,
) -> Result<Self, Box<dyn Reflect>>
fn take_from_reflect( reflect: Box<dyn Reflect>, ) -> Result<Self, Box<dyn Reflect>>
Self using,
constructing the value using from_reflect if that fails. Read moreSourceimpl GetTypeRegistration for DrawOrder
impl GetTypeRegistration for DrawOrder
Sourcefn get_type_registration() -> TypeRegistration
fn get_type_registration() -> TypeRegistration
TypeRegistration for this type.Sourcefn register_type_dependencies(registry: &mut TypeRegistry)
fn register_type_dependencies(registry: &mut TypeRegistry)
Sourceimpl MulAssign for DrawOrder
impl MulAssign for DrawOrder
Sourcefn mul_assign(&mut self, rhs: DrawOrder)
fn mul_assign(&mut self, rhs: DrawOrder)
*= operation. Read moreSourceimpl MulAssign<&DrawOrder> for DrawOrder
impl MulAssign<&DrawOrder> for DrawOrder
Sourcefn mul_assign(&mut self, rhs: &DrawOrder)
fn mul_assign(&mut self, rhs: &DrawOrder)
*= operation. Read moreSourceimpl MulAssign<&DrawOrder> for f32
impl MulAssign<&DrawOrder> for f32
Sourcefn mul_assign(&mut self, rhs: &DrawOrder)
fn mul_assign(&mut self, rhs: &DrawOrder)
*= operation. Read moreSourceimpl MulAssign<DrawOrder> for f32
impl MulAssign<DrawOrder> for f32
Sourcefn mul_assign(&mut self, rhs: DrawOrder)
fn mul_assign(&mut self, rhs: DrawOrder)
*= operation. Read moreSourceimpl MulAssign<f32> for DrawOrder
impl MulAssign<f32> for DrawOrder
Sourcefn mul_assign(&mut self, rhs: f32)
fn mul_assign(&mut self, rhs: f32)
*= operation. Read moreSourceimpl Reflect for DrawOrder
impl Reflect for DrawOrder
Sourcefn get_represented_type_info(&self) -> Option<&'static TypeInfo>
fn get_represented_type_info(&self) -> Option<&'static TypeInfo>
Sourcefn as_any_mut(&mut self) -> &mut (dyn Any + 'static)
fn as_any_mut(&mut self) -> &mut (dyn Any + 'static)
&mut dyn Any.Sourcefn into_reflect(self: Box<DrawOrder>) -> Box<dyn Reflect>
fn into_reflect(self: Box<DrawOrder>) -> Box<dyn Reflect>
Sourcefn as_reflect(&self) -> &(dyn Reflect + 'static)
fn as_reflect(&self) -> &(dyn Reflect + 'static)
Sourcefn as_reflect_mut(&mut self) -> &mut (dyn Reflect + 'static)
fn as_reflect_mut(&mut self) -> &mut (dyn Reflect + 'static)
Sourcefn clone_value(&self) -> Box<dyn Reflect>
fn clone_value(&self) -> Box<dyn Reflect>
Reflect trait object. Read moreSourcefn set(&mut self, value: Box<dyn Reflect>) -> Result<(), Box<dyn Reflect>>
fn set(&mut self, value: Box<dyn Reflect>) -> Result<(), Box<dyn Reflect>>
Sourcefn reflect_kind(&self) -> ReflectKind
fn reflect_kind(&self) -> ReflectKind
Sourcefn reflect_ref(&self) -> ReflectRef<'_>
fn reflect_ref(&self) -> ReflectRef<'_>
Sourcefn reflect_mut(&mut self) -> ReflectMut<'_>
fn reflect_mut(&mut self) -> ReflectMut<'_>
Sourcefn reflect_owned(self: Box<DrawOrder>) -> ReflectOwned
fn reflect_owned(self: Box<DrawOrder>) -> ReflectOwned
Sourcefn reflect_partial_eq(&self, value: &(dyn Reflect + 'static)) -> Option<bool>
fn reflect_partial_eq(&self, value: &(dyn Reflect + 'static)) -> Option<bool>
Sourcefn apply(&mut self, value: &(dyn Reflect + 'static))
fn apply(&mut self, value: &(dyn Reflect + 'static))
Sourcefn reflect_hash(&self) -> Option<u64>
fn reflect_hash(&self) -> Option<u64>
Sourcefn debug(&self, f: &mut Formatter<'_>) -> Result<(), Error>
fn debug(&self, f: &mut Formatter<'_>) -> Result<(), Error>
Sourcefn serializable(&self) -> Option<Serializable<'_>>
fn serializable(&self) -> Option<Serializable<'_>>
Sourcefn is_dynamic(&self) -> bool
fn is_dynamic(&self) -> bool
Sourceimpl RemAssign for DrawOrder
impl RemAssign for DrawOrder
Sourcefn rem_assign(&mut self, rhs: DrawOrder)
fn rem_assign(&mut self, rhs: DrawOrder)
%= operation. Read moreSourceimpl RemAssign<&DrawOrder> for DrawOrder
impl RemAssign<&DrawOrder> for DrawOrder
Sourcefn rem_assign(&mut self, rhs: &DrawOrder)
fn rem_assign(&mut self, rhs: &DrawOrder)
%= operation. Read moreSourceimpl RemAssign<&DrawOrder> for f32
impl RemAssign<&DrawOrder> for f32
Sourcefn rem_assign(&mut self, rhs: &DrawOrder)
fn rem_assign(&mut self, rhs: &DrawOrder)
%= operation. Read moreSourceimpl RemAssign<DrawOrder> for f32
impl RemAssign<DrawOrder> for f32
Sourcefn rem_assign(&mut self, rhs: DrawOrder)
fn rem_assign(&mut self, rhs: DrawOrder)
%= operation. Read moreSourceimpl RemAssign<f32> for DrawOrder
impl RemAssign<f32> for DrawOrder
Sourcefn rem_assign(&mut self, rhs: f32)
fn rem_assign(&mut self, rhs: f32)
%= operation. Read moreSourceimpl Serialize for DrawOrder
impl Serialize for DrawOrder
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
impl StructuralPartialEq for DrawOrder
Sourceimpl SubAssign for DrawOrder
impl SubAssign for DrawOrder
Sourcefn sub_assign(&mut self, rhs: DrawOrder)
fn sub_assign(&mut self, rhs: DrawOrder)
-= operation. Read moreSourceimpl SubAssign<&DrawOrder> for DrawOrder
impl SubAssign<&DrawOrder> for DrawOrder
Sourcefn sub_assign(&mut self, rhs: &DrawOrder)
fn sub_assign(&mut self, rhs: &DrawOrder)
-= operation. Read moreSourceimpl SubAssign<&DrawOrder> for f32
impl SubAssign<&DrawOrder> for f32
Sourcefn sub_assign(&mut self, rhs: &DrawOrder)
fn sub_assign(&mut self, rhs: &DrawOrder)
-= operation. Read moreSourceimpl SubAssign<DrawOrder> for f32
impl SubAssign<DrawOrder> for f32
Sourcefn sub_assign(&mut self, rhs: DrawOrder)
fn sub_assign(&mut self, rhs: DrawOrder)
-= operation. Read moreSourceimpl SubAssign<f32> for DrawOrder
impl SubAssign<f32> for DrawOrder
Sourcefn sub_assign(&mut self, rhs: f32)
fn sub_assign(&mut self, rhs: f32)
-= operation. Read moreSourceimpl TupleStruct for DrawOrder
impl TupleStruct for DrawOrder
Sourcefn field(&self, index: usize) -> Option<&(dyn Reflect + 'static)>
fn field(&self, index: usize) -> Option<&(dyn Reflect + 'static)>
index as a
&dyn Reflect.Sourcefn field_mut(&mut self, index: usize) -> Option<&mut (dyn Reflect + 'static)>
fn field_mut(&mut self, index: usize) -> Option<&mut (dyn Reflect + 'static)>
index
as a &mut dyn Reflect.Sourcefn iter_fields(&self) -> TupleStructFieldIter<'_>
fn iter_fields(&self) -> TupleStructFieldIter<'_>
Sourcefn clone_dynamic(&self) -> DynamicTupleStruct
fn clone_dynamic(&self) -> DynamicTupleStruct
DynamicTupleStruct.Sourceimpl TypePath for DrawOrder
impl TypePath for DrawOrder
Sourcefn type_path() -> &'static str
fn type_path() -> &'static str
Sourcefn short_type_path() -> &'static str
fn short_type_path() -> &'static str
Sourcefn type_ident() -> Option<&'static str>
fn type_ident() -> Option<&'static str>
Sourcefn crate_name() -> Option<&'static str>
fn crate_name() -> Option<&'static str>